@@ -14,6 +14,7 @@ from github.GithubException import RateLimitExceededException, TwoFactorExceptio
 
 from sickchill import settings
 from sickchill.helper.common import dateTimeFormat
+from sickchill.init_helpers import get_current_version
 from sickchill.oldbeard import classes
 
 # log levels
@@ -214,12 +215,12 @@ class Logger(object):
 
             update_manager = UpdateManager()
             update_manager.check_for_new_version()
-            commits_behind = update_manager.get_num_commits_behind()
+            need_update = update_manager.need_update()
         except Exception:
             submitter_result = "Could not check if your SickChill is updated, unable to submit issue ticket to GitHub!"
             return submitter_result, issue_id
 
-        if commits_behind is None or commits_behind > 0:
+        if need_update:
             submitter_result = "Please update SickChill, unable to submit issue ticket to GitHub with an outdated version!"
             return submitter_result, issue_id
 
@@ -250,7 +251,7 @@ class Logger(object):
                 try:
                     title_error = str(cur_error.title)
                     if not title_error or title_error == "None":
-                        title_error = re.match(r"^[A-Za-z0-9\-\[\] :]+::\s\[[\w]{7}\]\s*(.*)$", cur_error.message).group(1)
+                        title_error = re.match(r"^[A-Za-z0-9\-\[\] :]+::\s\[\w{7}\]\s*(.*)$", cur_error.message).group(1)
 
                     if len(title_error) > 1000:
                         title_error = title_error[0:1000]
@@ -288,8 +289,7 @@ class Logger(object):
                     f"Python Version: **{sys.version[:120]}**".replace("\n", ""),
                     f"Operating System: **{platform.platform()}**",
                     f"Locale: {locale_name}",
-                    f"Branch: **{settings.BRANCH}**",
-                    f"Commit: SickChill/SickChill@{settings.CUR_COMMIT_HASH}",
+                    f"Version: **{get_current_version()}**",
                     log_link,
                     "### ERROR",
                     "```",
@@ -349,10 +349,10 @@ class Logger(object):
                     # clear error from error list
                     classes.ErrorViewer.errors.remove(cur_error)
         except RateLimitExceededException:
-            submitter_result = "Your Github user has exceeded its API rate limit, please try again later"
+            submitter_result = "Your GitHub user has exceeded its API rate limit, please try again later"
             issue_id = None
         except TwoFactorException:
-            submitter_result = "Your Github account requires Two-Factor Authentication, " "please change your auth method in the config"
+            submitter_result = "Your GitHub account requires Two-Factor Authentication, " "please change your auth method in the config"
             issue_id = None
         except Exception:
             self.logger.log(ERROR, traceback.format_exc())
@@ -416,7 +416,7 @@ def log_data(min_level, log_filter, log_search, max_lines):
         log_files.append(Wrapper.instance.log_file)
 
         for i in range(1, int(settings.LOG_NR)):
-            name = Wrapper.instance.log_file + "." + str(i)
+            name = f"{Wrapper.instance.log_file}.{i}"
             if not os.path.isfile(name):
                 break
             log_files.append(name)
