@@ -5,7 +5,7 @@ from subliminal.providers import ParserBeautifulSoup
 
 
 class BS4Parser(object):
-    def __init__(self, markup, parsers, language="html", **kwargs):
+    def __init__(self, markup, parsers=None, language="html", **kwargs):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             if isinstance(parsers, str):
@@ -16,6 +16,9 @@ class BS4Parser(object):
             elif language == "xml":
                 extra_parsers = ["lxml-xml", "html.parser"]
 
+            if parsers is None:
+                parsers = extra_parsers
+
             try:
                 self.soup = ParserBeautifulSoup(markup, parsers, **kwargs)
             except FeatureNotFound:
