@@ -46,9 +46,9 @@ class Events(threading.Thread):
 
             # exiting thread
             self.stop.clear()
-        except Exception as e:
-            logger.exception("Exception generated in thread " + self.name + ": " + str(e))
-            logger.debug(repr(traceback.format_exc()))
+        except Exception as error:
+            logger.exception(f"Exception generated in thread {self.name}: {error}")
+            logger.debug(traceback.format_exc())
 
     # System Events
     class SystemEvent(Event):
