@@ -105,9 +105,6 @@ class NameParser(object):
                 if result.series_name:
                     result.series_name = self.clean_series_name(result.series_name)
                     result.score += 1
-                else:
-                    # Reduce the regex score when there is no name.
-                    result.score -= 20
 
             if "series_num" in named_groups and match.group("series_num"):
                 result.score += 1
@@ -295,7 +292,7 @@ class NameParser(object):
             new_season_numbers = list(set(new_season_numbers))  # remove duplicates
             if len(new_season_numbers) > 1:
                 raise InvalidNameException(
-                    f"Scene numbering results episodes from seasons {new_season_numbers}, " f"(i.e. more than one) and sickchill does not support this. Sorry."
+                    f"Scene numbering results episodes from seasons {new_season_numbers}, (i.e. more than one) and sickchill does not support this. Sorry."
                 )
 
             # I guess it's possible that we'd have duplicate episodes too, so lets
@@ -585,7 +582,7 @@ class ParseResult(object):
 
         to_return += f" [ABD: {self.is_air_by_date}] [ANIME: {self.is_anime}] [whichReg: {self.which_regex}] Score: {self.score}"
 
-        return to_return
+        return re.sub(r"[ ]+", " ", to_return)
 
     @property
     def is_air_by_date(self):
