@@ -240,10 +240,10 @@ class Notifier(object):
                 else:
                     logger.warning("Download notification error: {0}".format(self.last_err))
 
-    def notify_git_update(self, new_version="??"):
+    def notify_update(self, new_version="??"):
         """
         Send a notification that SickChill was updated
-        new_version: The commit SickChill was updated to
+        new_version: The version SickChill was updated to
         """
         if settings.USE_EMAIL:
             to = self._generate_recipients(None)
@@ -252,12 +252,12 @@ class Notifier(object):
             else:
                 try:
                     msg = MIMEMultipart("alternative")
-                    msg.attach(MIMEText("SickChill Notification - Updated\n" "Commit: {}\n\n" "Powered by SickChill.".format(new_version)))
+                    msg.attach(MIMEText("SickChill Notification - Updated\n" "Version: {}\n\n" "Powered by SickChill.".format(new_version)))
                     msg.attach(
                         MIMEText(
                             '<body style="font-family:Helvetica, Arial, sans-serif;">'
                             "<h3>SickChill Notification - Updated</h3><br>"
-                            "<p>Commit: <b>{}</b></p><br><br>"
+                            "<p>Version: <b>{}</b></p><br><br>"
                             '<footer style="margin-top: 2.5em; padding: .7em 0; '
                             'color: #777; border-top: #BBB solid 1px;">'
                             "Powered by SickChill.</footer></body>".format(new_version),
@@ -358,10 +358,10 @@ class Notifier(object):
         logger.debug("HOST: {0}; PORT: {1}; FROM: {2}, TLS: {3}, USER: {4}, PWD: {5}, TO: {6}".format(host, port, smtp_from, use_tls, user, pwd, to))
         try:
             srv = smtplib.SMTP(host, int(port))
-        except Exception as e:
-            logger.warning("Exception generated while sending e-mail: " + str(e))
+        except Exception as error:
+            logger.warning(f"Exception generated while sending e-mail: {error}")
             # logger.debug(traceback.format_exc())
-            self.last_err = "{0}".format(e)
+            self.last_err = f"{error}"
             return False
 
         if smtpDebug:
@@ -381,8 +381,8 @@ class Notifier(object):
             srv.sendmail(smtp_from, to, msg.as_string())
             srv.quit()
             return True
-        except Exception as e:
-            self.last_err = "{0}".format(e)
+        except Exception as error:
+            self.last_err = f"{error}"
             return False
 
     @staticmethod
