@@ -6,12 +6,12 @@ import urllib.request
 from sickchill import logger, settings
 from sickchill.oldbeard.common import (
     NOTIFY_DOWNLOAD,
-    NOTIFY_GIT_UPDATE,
-    NOTIFY_GIT_UPDATE_TEXT,
     NOTIFY_LOGIN,
     NOTIFY_LOGIN_TEXT,
     NOTIFY_SNATCH,
     NOTIFY_SUBTITLE_DOWNLOAD,
+    NOTIFY_UPDATE,
+    NOTIFY_UPDATE_TEXT,
     notifyStrings,
 )
 
@@ -48,26 +48,26 @@ class Notifier(object):
         # send the request to Free Mobile
         try:
             urllib.request.urlopen(req)
-        except IOError as e:
-            if hasattr(e, "code"):
-                if e.code == 400:
+        except IOError as error:
+            if hasattr(error, "code"):
+                if error.code == 400:
                     message = "Missing parameter(s)."
                     logger.exception(message)
                     return False, message
-                if e.code == 402:
+                if error.code == 402:
                     message = "Too much SMS sent in a short time."
                     logger.exception(message)
                     return False, message
-                if e.code == 403:
+                if error.code == 403:
                     message = "API service isn't enabled in your account or ID / API key is incorrect."
                     logger.exception(message)
                     return False, message
-                if e.code == 500:
+                if error.code == 500:
                     message = "Server error. Please retry in few moment."
                     logger.exception(message)
                     return False, message
-        except Exception as e:
-            message = "Error while sending SMS: {0}".format(e)
+        except Exception as error:
+            message = f"Error while sending SMS: {error}"
             logger.exception(message)
             return False, message
 
@@ -87,10 +87,10 @@ class Notifier(object):
         if settings.FREEMOBILE_NOTIFY_ONSUBTITLEDOWNLOAD:
             self._notifyFreeMobile(title, ep_name + ": " + lang)
 
-    def notify_git_update(self, new_version="??"):
+    def notify_update(self, new_version="??"):
         if settings.USE_FREEMOBILE:
-            update_text = notifyStrings[NOTIFY_GIT_UPDATE_TEXT]
-            title = notifyStrings[NOTIFY_GIT_UPDATE]
+            update_text = notifyStrings[NOTIFY_UPDATE_TEXT]
+            title = notifyStrings[NOTIFY_UPDATE]
             self._notifyFreeMobile(title, update_text + new_version)
 
     def notify_login(self, ipaddress=""):
