@@ -23,9 +23,9 @@ class Notifier(object):
         if settings.GROWL_NOTIFY_ONSUBTITLEDOWNLOAD:
             self._sendGrowl(common.notifyStrings[common.NOTIFY_SUBTITLE_DOWNLOAD], ep_name + ": " + lang)
 
-    def notify_git_update(self, new_version="??"):
-        update_text = common.notifyStrings[common.NOTIFY_GIT_UPDATE_TEXT]
-        title = common.notifyStrings[common.NOTIFY_GIT_UPDATE]
+    def notify_update(self, new_version="??"):
+        update_text = common.notifyStrings[common.NOTIFY_UPDATE_TEXT]
+        title = common.notifyStrings[common.NOTIFY_UPDATE]
         self._sendGrowl(title, update_text + new_version)
 
     def notify_login(self, ipaddress=""):
@@ -116,8 +116,8 @@ class Notifier(object):
                         return self._send_growl(opts, message)
                     else:
                         return False
-            except Exception as e:
-                logger.warning("GROWL: Unable to send growl to " + opts["host"] + ":" + str(opts["port"]) + " - " + str(e))
+            except Exception as error:
+                logger.warning(f"GROWL: Unable to send growl to {opts['host']}:{opts['port']} - {error}")
                 return False
 
     def _sendRegistration(self, host=None, password=None, name="SickChill Notification"):
@@ -152,13 +152,13 @@ class Notifier(object):
         register.add_notification("Test", True)
         register.add_notification(common.notifyStrings[common.NOTIFY_SNATCH], True)
         register.add_notification(common.notifyStrings[common.NOTIFY_DOWNLOAD], True)
-        register.add_notification(common.notifyStrings[common.NOTIFY_GIT_UPDATE], True)
+        register.add_notification(common.notifyStrings[common.NOTIFY_UPDATE], True)
 
         if opts["password"]:
             register.set_password(opts["password"])
 
         try:
             return self._send(opts["host"], opts["port"], register.encode(), opts["debug"])
-        except Exception as e:
-            logger.warning("GROWL: Unable to send growl to " + opts["host"] + ":" + str(opts["port"]) + " - " + str(e))
+        except Exception as error:
+            logger.warning(f"GROWL: Unable to send growl to {opts['host']}:{opts['port']} - {error}")
             return False
