@@ -4,12 +4,12 @@ import urllib.request
 from sickchill import logger, settings
 from sickchill.oldbeard.common import (
     NOTIFY_DOWNLOAD,
-    NOTIFY_GIT_UPDATE,
-    NOTIFY_GIT_UPDATE_TEXT,
     NOTIFY_LOGIN,
     NOTIFY_LOGIN_TEXT,
     NOTIFY_SNATCH,
     NOTIFY_SUBTITLE_DOWNLOAD,
+    NOTIFY_UPDATE,
+    NOTIFY_UPDATE_TEXT,
     notifyStrings,
 )
 
@@ -64,8 +64,8 @@ class Notifier(object):
             message = "Join message sent successfully."
             logger.debug("Join message returned : {0}".format(message))
             success = True
-        except Exception as e:
-            message = "Error while sending Join message: {0} ".format(e)
+        except Exception as error:
+            message = f"Error while sending Join message: {error}"
         finally:
             logger.info(message)
             return success, message
@@ -101,15 +101,15 @@ class Notifier(object):
         if settings.JOIN_NOTIFY_ONSUBTITLEDOWNLOAD:
             self._notify_join(title, "{0}: {1}".format(ep_name, lang))
 
-    def notify_git_update(self, new_version="??"):
+    def notify_update(self, new_version="??"):
         """
         Sends a Join notification for git updates
 
         :param new_version: The new version available from git
         """
         if settings.USE_JOIN:
-            update_text = notifyStrings[NOTIFY_GIT_UPDATE_TEXT]
-            title = notifyStrings[NOTIFY_GIT_UPDATE]
+            update_text = notifyStrings[NOTIFY_UPDATE_TEXT]
+            title = notifyStrings[NOTIFY_UPDATE]
             self._notify_join(title, update_text + new_version)
 
     def notify_login(self, ipaddress=""):
