@@ -19,7 +19,7 @@ class Notifier(object):
         self._notifyNMJ()
 
     @staticmethod
-    def notify_git_update(new_version):
+    def notify_update(new_version):
         return False
         # Not implemented, no reason to start scanner.
 
@@ -64,8 +64,8 @@ class Notifier(object):
                         settings.NMJv2_DATABASE = db_path
                         return True
 
-        except IOError as e:
-            logger.warning("Warning: Couldn't contact popcorn hour on host {0}: {1}".format(host, e))
+        except IOError as error:
+            logger.warning(f"Warning: Couldn't contact popcorn hour on host {host}: {error}")
             return False
         return False
 
@@ -91,20 +91,20 @@ class Notifier(object):
             url = "http://{}:8008/metadata_database?arg0=scanner_start&arg1{}&arg2=background&arg3=".format(host, settings.NMJv2_DATABASE)
             logger.debug("Try to mount network drive via url: {0}".format(host))
             response2 = requests.get(url)
-        except IOError as e:
-            logger.warning("Warning: Couldn't contact popcorn hour on host {0}: {1}".format(host, e))
+        except IOError as error:
+            logger.warning(f"Warning: Couldn't contact popcorn hour on host {host}: {error}")
             return False
         try:
             et = ElementTree.fromstring(response1.text)
             result1 = et.findtext("returnValue")
-        except SyntaxError as e:
-            logger.exception("Unable to parse XML returned from the Popcorn Hour: update_scandir, {0}".format(e))
+        except SyntaxError as error:
+            logger.exception(f"Unable to parse XML returned from the Popcorn Hour: update_scandir, {error}")
             return False
         try:
             et = ElementTree.fromstring(response2.text)
             result2 = et.findtext("returnValue")
-        except SyntaxError as e:
-            logger.exception("Unable to parse XML returned from the Popcorn Hour: scanner_start, {0}".format(e))
+        except SyntaxError as error:
+            logger.exception(f"Unable to parse XML returned from the Popcorn Hour: scanner_start, {error}")
             return False
 
         # if the result was a number then consider that an error
@@ -120,12 +120,12 @@ class Notifier(object):
         ]
         if int(result1) > 0:
             index = error_codes.index(result1)
-            logger.exception("Popcorn Hour returned an error: {0}".format((error_messages[index])))
+            logger.exception(f"Popcorn Hour returned an error: {error_messages[index]}")
             return False
         else:
             if int(result2) > 0:
                 index = error_codes.index(result2)
-                logger.exception("Popcorn Hour returned an error: {0}".format((error_messages[index])))
+                logger.exception(f"Popcorn Hour returned an error: {error_messages[index]}")
                 return False
             else:
                 logger.info("NMJv2 started background scan")
