@@ -25,9 +25,9 @@ class Notifier(object):
         if settings.TWILIO_NOTIFY_ONSUBTITLEDOWNLOAD:
             self._notifyTwilio(common.notifyStrings[common.NOTIFY_SUBTITLE_DOWNLOAD] + " " + ep_name + ": " + lang)
 
-    def notify_git_update(self, new_version):
+    def notify_update(self, new_version):
         if settings.USE_TWILIO:
-            update_text = common.notifyStrings[common.NOTIFY_GIT_UPDATE_TEXT]
+            update_text = common.notifyStrings[common.NOTIFY_UPDATE_TEXT]
             self._notifyTwilio(update_text + new_version)
 
     def notify_login(self, ipaddress=""):
@@ -65,10 +65,10 @@ class Notifier(object):
                 to=settings.TWILIO_TO_NUMBER,
                 from_=self.number.phone_number,
             )
-        except TwilioException as e:
-            logger.exception("Twilio notification failed:" + str(e))
+        except TwilioException as error:
+            logger.exception(f"Twilio notification failed: {error}")
 
             if allow_raise:
-                raise e
+                raise error
 
         return True
