@@ -5,11 +5,18 @@ import re
 import stat
 import subprocess
 from pathlib import Path
+from typing import TYPE_CHECKING, Union
+
+if TYPE_CHECKING:
+    from processTV import ParseResult
+    from sickchill.tv import TVShow
+
+from guessit import guessit
 
 import sickchill.helper.common
 import sickchill.oldbeard.subtitles
 from sickchill import adba, logger, settings
-from sickchill.helper.common import get_extension, is_rar_file, remove_extension, replace_extension, SUBTITLE_EXTENSIONS
+from sickchill.helper.common import episode_num, get_extension, is_rar_file, remove_extension, replace_extension, SUBTITLE_EXTENSIONS
 from sickchill.helper.exceptions import EpisodeNotFoundException, EpisodePostProcessingFailedException, ShowDirectoryNotFoundException
 from sickchill.show.History import History
 from sickchill.show.Show import Show
@@ -112,19 +119,19 @@ class PostProcessor(object):
 
             # see if it's bigger than our old file
             if os.path.getsize(existing_file) > os.path.getsize(self.directory):
-                self._log(_(f"File {existing_file} is larger than {self.directory}"), logger.DEBUG)
+                self._log(_("File {existing_file} is larger than {directory}").format(existing_file=existing_file, directory=self.directory), logger.DEBUG)
                 return PostProcessor.EXISTS_LARGER
 
             elif os.path.getsize(existing_file) == os.path.getsize(self.directory):
-                self._log(_(f"File {existing_file} is the same size as {self.directory}"), logger.DEBUG)
+                self._log(_("File {existing_file} is the same size as {directory}").format(existing_file=existing_file, directory=self.directory), logger.DEBUG)
                 return PostProcessor.EXISTS_SAME
 
             else:
-                self._log(_(f"File {existing_file} is smaller than {self.directory}"), logger.DEBUG)
+                self._log(_("File {existing_file} is smaller than {directory}").format(existing_file=existing_file, directory=self.directory), logger.DEBUG)
                 return PostProcessor.EXISTS_SMALLER
 
         else:
-            self._log(_(f"File {existing_file} doesn't exist so there's no worries about replacing it"), logger.DEBUG)
+            self._log(_("File {existing_file} doesn't exist so there's no worries about replacing it").format(existing_file=existing_file), logger.DEBUG)
             return PostProcessor.DOESNT_EXIST
 
     def list_associated_files(self, file_path, subtitles_only=False, subfolders=False, rename=False):
@@ -188,16 +195,29 @@ class PostProcessor(object):
 
         if file_path_list_to_allow or file_path_list_to_delete:
             self._log(
-                _(f"Found the following associated files for {file_path}: {file_path_list_to_allow + file_path_list_to_delete}"), logger.DEBUG
+                _("Found the following associated files for {file_path}: {allow_and_delete}").format(
+                    file_path=file_path, allow_and_delete=file_path_list_to_allow + file_path_list_to_delete
+                ),
+                logger.DEBUG,
             )
             if file_path_list_to_delete:
-                self._log(_(f"Deleting non-allowed associated files for {file_path}: {file_path_list_to_delete}"), logger.DEBUG)
+                self._log(
+                    _("Deleting non-allowed associated files for {file_path}: {file_path_list_to_delete}").format(
+                        file_path=file_path, file_path_list_to_delete=file_path_list_to_delete
+                    ),
+                    logger.DEBUG,
+                )
                 # Delete all extensions the user doesn't allow
                 self._delete(file_path_list_to_delete)
             if file_path_list_to_allow:
-                self._log(_(f"Allowing associated files for {file_path}: {file_path_list_to_allow}"), logger.DEBUG)
+                self._log(
+                    _("Allowing associated files for {file_path}: {file_path_list_to_allow}").format(
+                        file_path=file_path, file_path_list_to_allow=file_path_list_to_allow
+                    ),
+                    logger.DEBUG,
+                )
         else:
-            self._log(_(f"No associated files for {file_path} were found during this pass"), logger.DEBUG)
+            self._log(_("No associated files for {file_path} were found during this pass").format(file_path=file_path), logger.DEBUG)
 
         return file_path_list_to_allow
 
@@ -223,22 +243,22 @@ class PostProcessor(object):
             file_list += self.list_associated_files(file_path, subfolders=True)
 
         if not file_list:
-            self._log(_(f"There were no files associated with {file_path}, not deleting anything"), logger.DEBUG)
+            self._log(_("There were no files associated with {file_path}, not deleting anything").format(file_path=file_path), logger.DEBUG)
             return
 
         # delete the file and any other files which we want to delete
         for cur_file in file_list:
             if os.path.isfile(cur_file):
-                self._log(_(f"Deleting file {cur_file}"), logger.DEBUG)
+                self._log(_("Deleting file {cur_file}").format(cur_file=cur_file), logger.DEBUG)
                 # check first the read-only attribute
                 file_attribute = os.stat(cur_file)[0]
                 if not file_attribute & stat.S_IWRITE:
                     # File is read-only, so make it writeable
-                    self._log(_(f"Read only mode on file {cur_file} Will try to make it writeable"), logger.DEBUG)
+                    self._log(_("Read only mode on file {cur_file} Will try to make it writeable").format(cur_file=cur_file), logger.DEBUG)
                     try:
                         os.chmod(cur_file, stat.S_IWRITE)
                     except Exception:
-                        self._log(_(f"Cannot change permissions of {cur_file}"), logger.WARNING)
+                        self._log(_("Cannot change permissions of {cur_file}").format(cur_file=cur_file), logger.WARNING)
 
                 os.remove(cur_file)
 
@@ -270,7 +290,7 @@ class PostProcessor(object):
             file_list += self.list_associated_files(file_path, subtitles_only=True, subfolders=subfolders)
 
         if not file_list:
-            self._log(_(f"There were no files associated with {file_path}, not moving anything"), logger.DEBUG)
+            self._log(_("There were no files associated with {file_path}, not moving anything").format(file_path=file_path), logger.DEBUG)
             return
 
         # deal with all files
@@ -304,7 +324,7 @@ class PostProcessor(object):
                 subs_new_path = os.path.join(new_path, settings.SUBTITLES_DIR)
                 dir_exists = helpers.makeDir(subs_new_path)
                 if not dir_exists:
-                    logger.exception(_(f"Unable to create subtitles folder {subs_new_path}"))
+                    logger.exception(_("Unable to create subtitles folder {subs_new_path}").format(subs_new_path=subs_new_path))
                 else:
                     helpers.chmodAsParent(subs_new_path)
                 new_file_path = os.path.join(subs_new_path, new_filename)
@@ -325,12 +345,17 @@ class PostProcessor(object):
 
         def _int_move(cur_file_path, new_file_path):
 
-            self._log(_(f"Moving file from {cur_file_path} to {new_file_path}"), logger.DEBUG)
+            self._log(_("Moving file from {cur_file_path} to {new_file_path}").format(cur_file_path=cur_file_path, new_file_path=new_file_path), logger.DEBUG)
             try:
                 helpers.moveFile(cur_file_path, new_file_path)
                 helpers.chmodAsParent(new_file_path)
-            except (IOError, OSError) as e:
-                self._log(_(f"Unable to move file from {cur_file_path} to {new_file_path}: {str(e)}"), logger.ERROR)
+            except (IOError, OSError) as error:
+                self._log(
+                    _("Unable to move file from {cur_file_path} to {new_file_path}: {error}").format(
+                        cur_file_path=cur_file_path, new_file_path=new_file_path, error=error
+                    ),
+                    logger.ERROR,
+                )
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_move, subtitles=subtitles)
@@ -347,12 +372,17 @@ class PostProcessor(object):
 
         def _int_copy(cur_file_path, new_file_path):
 
-            self._log(_(f"Copying file from {cur_file_path} to {new_file_path}"), logger.DEBUG)
+            self._log(_("Copying file from {cur_file_path} to {new_file_path}").format(cur_file_path=cur_file_path, new_file_path=new_file_path), logger.DEBUG)
             try:
                 helpers.copyFile(cur_file_path, new_file_path)
                 helpers.chmodAsParent(new_file_path)
-            except (IOError, OSError) as e:
-                self._log(_(f"Unable to copy file from {cur_file_path} to {new_file_path}: {str(e)}"), logger.ERROR)
+            except (IOError, OSError) as error:
+                self._log(
+                    _("Unable to copy file from {cur_file_path} to {new_file_path}: {error}").format(
+                        cur_file_path=cur_file_path, new_file_path=new_file_path, error=error
+                    ),
+                    logger.ERROR,
+                )
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_copy, subtitles=subtitles)
@@ -369,12 +399,19 @@ class PostProcessor(object):
 
         def _int_hard_link(cur_file_path, new_file_path):
 
-            self._log(_(f"Hard linking file from {cur_file_path} to {new_file_path}"), logger.DEBUG)
+            self._log(
+                _("Hard linking file from {cur_file_path} to {new_file_path}").format(cur_file_path=cur_file_path, new_file_path=new_file_path), logger.DEBUG
+            )
             try:
                 helpers.hardlinkFile(cur_file_path, new_file_path)
                 helpers.chmodAsParent(new_file_path)
-            except (IOError, OSError) as e:
-                self._log(_(f"Unable to link file from {cur_file_path} to {new_file_path}: {str(e)}"), logger.ERROR)
+            except (IOError, OSError) as error:
+                self._log(
+                    _("Unable to link file from {cur_file_path} to {new_file_path}: {error}").format(
+                        cur_file_path=cur_file_path, new_file_path=new_file_path, error=error
+                    ),
+                    logger.ERROR,
+                )
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_hard_link, subtitles=subtitles)
@@ -391,12 +428,22 @@ class PostProcessor(object):
 
         def _int_move_and_sym_link(cur_file_path, new_file_path):
 
-            self._log(_(f"Moving then symbolically linking file from {cur_file_path} to {new_file_path}"), logger.DEBUG)
+            self._log(
+                _("Moving then symbolically linking file from {cur_file_path} to {new_file_path}").format(
+                    cur_file_path=cur_file_path, new_file_path=new_file_path
+                ),
+                logger.DEBUG,
+            )
             try:
                 helpers.moveAndSymlinkFile(cur_file_path, new_file_path)
                 helpers.chmodAsParent(new_file_path)
-            except (IOError, OSError) as e:
-                self._log(_(f"Unable to link file from {cur_file_path} to {new_file_path}: {str(e)}"), logger.ERROR)
+            except (IOError, OSError) as error:
+                self._log(
+                    _("Unable to link file from {cur_file_path} to {new_file_path}: {error}").format(
+                        cur_file_path=cur_file_path, new_file_path=new_file_path, error=error
+                    ),
+                    logger.ERROR,
+                )
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_move_and_sym_link, subtitles=subtitles)
@@ -413,12 +460,22 @@ class PostProcessor(object):
 
         def _int_sym_link(cur_file_path, new_file_path):
 
-            self._log(_(f"Creating then symbolically linking file from {new_file_path} to {cur_file_path}"), logger.DEBUG)
+            self._log(
+                _("Creating then symbolically linking file from {new_file_path} to {cur_file_path}").format(
+                    cur_file_path=cur_file_path, new_file_path=new_file_path
+                ),
+                logger.DEBUG,
+            )
             try:
                 os.symlink(cur_file_path, new_file_path)
                 helpers.chmodAsParent(cur_file_path)
-            except (IOError, OSError) as e:
-                self._log(_("Unable to link file {cur_file_path} to {new_file_path}: {str(e)}"), logger.ERROR)
+            except (IOError, OSError) as error:
+                self._log(
+                    _("Unable to link file {cur_file_path} to {new_file_path}: {error}").format(
+                        cur_file_path=cur_file_path, new_file_path=new_file_path, error=error
+                    ),
+                    logger.ERROR,
+                )
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_sym_link, subtitles=subtitles)
@@ -473,8 +530,13 @@ class PostProcessor(object):
             to_return = (show, season, [], quality, version)
 
             qual_str = common.Quality.qualityStrings[quality] if quality is not None else quality
-            self._log(_(f"Found result in history for {show.name if show else 'UNDEFINED'} - Season: {season} - "
-                        f"Quality: {qual_str} - Version: {version}"), logger.DEBUG)
+            result_name = show.name if show else "UNDEFINED"
+            self._log(
+                _("Found result in history for {result_name} - Season: {season} - Quality: {qual_str} - Version: {version}").format(
+                    result_name=result_name, season=season, qual_str=qual_str, version=version
+                ),
+                logger.DEBUG,
+            )
 
             return to_return
 
@@ -506,11 +568,11 @@ class PostProcessor(object):
 
         else:
             logger.debug("Parse result not sufficient (all following have to be set). will not save release name")
-            logger.debug("Parse result(series_name): " + str(parse_result.series_name))
-            logger.debug("Parse result(season_number): " + str(parse_result.season_number))
-            logger.debug("Parse result(episode_numbers): " + str(parse_result.episode_numbers))
-            logger.debug(" or Parse result(air_date): " + str(parse_result.air_date))
-            logger.debug("Parse result(release_group): " + str(parse_result.release_group))
+            logger.debug(f"Parse result(series_name): {parse_result.series_name}")
+            logger.debug(f"Parse result(season_number): {parse_result.season_number}")
+            logger.debug(f"Parse result(episode_numbers): {parse_result.episode_numbers}")
+            logger.debug(f" or Parse result(air_date): {parse_result.air_date}")
+            logger.debug(f"Parse result(release_group): {parse_result.release_group}")
 
     def _analyze_name(self, name):
         """
@@ -527,15 +589,12 @@ class PostProcessor(object):
         if not name:
             return to_return
 
-        logger.debug("Analyzing name " + name)
+        logger.debug(f"Analyzing name {name}")
 
         name = helpers.remove_non_release_groups(remove_extension(name))
 
-        # parse the name to break it into show name, season, and episode
-        try:
-            parse_result = NameParser(tryIndexers=True).parse(name)
-        except (InvalidNameException, InvalidShowException) as error:
-            logger.debug(f"{error}")
+        parse_result = guessit_findit(name)
+        if not parse_result:
             return to_return
 
         # show object
@@ -584,8 +643,8 @@ class PostProcessor(object):
             self._log(_("Adding the file to the anidb mylist"), logger.DEBUG)
             try:
                 self.anidbEpisode.add_to_mylist(status=1)  # status = 1 sets the status of the file to "internal HDD"
-            except Exception as e:
-                self._log("exception msg: " + str(e))
+            except Exception as error:
+                self._log(f"exception msg: {error}")
 
     def _find_info(self):
         """
@@ -609,7 +668,7 @@ class PostProcessor(object):
             # try to analyze the file + dir names together
             lambda: self._analyze_name(self.directory),
             # try to analyze the dir + file name together as one name
-            lambda: self._analyze_name(self.folder_name + " " + self.filename),
+            lambda: self._analyze_name(f"{self.folder_name} {self.filename}"),
         ]
 
         # attempt every possible method to get our info
@@ -645,7 +704,8 @@ class PostProcessor(object):
                 try:
                     airdate = episodes[0].toordinal()
                 except AttributeError:
-                    self._log(_(f"Could not convert to a valid airdate: {episodes[0]}"), logger.DEBUG)
+                    airdate_value = episodes[0]
+                    self._log(_("Could not convert to a valid airdate: {airdate_value}").format(airdate_value=airdate_value), logger.DEBUG)
                     episodes = []
                     continue
 
@@ -668,7 +728,7 @@ class PostProcessor(object):
                         season = int(sql_result[0]["season"])
                         episodes = [int(sql_result[0]["episode"])]
                     else:
-                        self._log("Unable to find episode with date " + str(episodes[0]) + " for show " + str(show.indexerid) + ", skipping", logger.DEBUG)
+                        self._log(f"Unable to find episode with date {episodes[0]} for show {show.indexerid}, skipping", logger.DEBUG)
                         # we don't want to leave dates in the episode list if we couldn't convert them to real episode numbers
                         episodes = []
                         continue
@@ -702,15 +762,15 @@ class PostProcessor(object):
 
         root_ep = None
         for cur_episode in episodes:
-            self._log("Retrieving episode object for " + str(season) + "x" + str(cur_episode), logger.DEBUG)
+            self._log(f"Retrieving episode object for {episode_num(season, cur_episode)}", logger.DEBUG)
 
             # now that we've figured out which episode this file is just load it manually
             try:
                 curEp = show.getEpisode(season, cur_episode)
                 if not curEp:
                     raise EpisodeNotFoundException()
-            except EpisodeNotFoundException as e:
-                self._log(_("Unable to create episode: ") + str(e), logger.DEBUG)
+            except EpisodeNotFoundException as error:
+                self._log(_("Unable to create episode: {error}").format(error=error), logger.DEBUG)
                 raise EpisodePostProcessingFailedException()
 
             # associate all the episodes together under a single root episode
@@ -749,25 +809,25 @@ class PostProcessor(object):
                 continue
 
             ep_quality = common.Quality.nameQuality(cur_name, ep_obj.show.is_anime)
-            self._log("Looking up quality for name " + cur_name + ", got " + common.Quality.qualityStrings[ep_quality], logger.DEBUG)
+            self._log(f"Looking up quality for name {cur_name}, got {common.Quality.qualityStrings[ep_quality]}", logger.DEBUG)
 
             # if we find a good one then use it
             if ep_quality != common.Quality.UNKNOWN:
-                logger.debug(cur_name + " looks like it has quality " + common.Quality.qualityStrings[ep_quality] + ", using that")
+                logger.debug(f"{cur_name} looks like it has quality {common.Quality.qualityStrings[ep_quality]}, using that")
                 return ep_quality
 
         # Try getting quality from the episode (snatched) status
         if ep_obj.status in common.Quality.SNATCHED + common.Quality.SNATCHED_PROPER + common.Quality.SNATCHED_BEST:
             ep_status_, ep_quality = common.Quality.splitCompositeStatus(ep_obj.status)
             if ep_quality != common.Quality.UNKNOWN:
-                self._log("The old status had a quality in it, using that: " + common.Quality.qualityStrings[ep_quality], logger.DEBUG)
+                self._log(f"The old status had a quality in it, using that: {common.Quality.qualityStrings[ep_quality]}", logger.DEBUG)
                 return ep_quality
 
         # Try guessing quality from the file name
         ep_quality = common.Quality.nameQuality(self.directory)
-        self._log("Guessing quality for name " + self.filename + ", got " + common.Quality.qualityStrings[ep_quality], logger.DEBUG)
+        self._log(f"Guessing quality for name {self.filename}, got {common.Quality.qualityStrings[ep_quality]}", logger.DEBUG)
         if ep_quality != common.Quality.UNKNOWN:
-            logger.debug(self.filename + " looks like it has quality " + common.Quality.qualityStrings[ep_quality] + ", using that")
+            logger.debug(f"{self.filename} looks like it has quality {common.Quality.qualityStrings[ep_quality]}, using that")
             return ep_quality
 
         return ep_quality
@@ -798,10 +858,10 @@ class PostProcessor(object):
                 )
                 out, err = p.communicate()
 
-                self._log(_(f"Script result: {str(out or err).strip()}"), logger.DEBUG)
+                self._log(_("Script result: {out}").format(out=(out or err).strip()), logger.DEBUG)
 
-            except Exception as e:
-                self._log(f"Unable to run extra_script: {str(e)}")
+            except Exception as error:
+                self._log(f"Unable to run extra_script: {error}")
 
     def _is_priority(self, ep_obj, new_ep_quality):
         """
@@ -855,19 +915,19 @@ class PostProcessor(object):
         :return: True on success, False on failure
         """
 
-        self._log("Processing " + self.directory + " (" + str(self.release_name) + ")")
+        self._log(_("Processing {directory} ({release_name})").format(directory=self.directory, release_name=self.release_name))
 
         if os.path.isdir(self.directory):
-            self._log(f"File {self.directory} seems to be a directory")
+            self._log(_("File {directory} seems to be a directory").format(directory=self.directory))
             return False
 
         if not os.path.exists(self.directory):
-            self._log(f"File {self.directory} doesn't exist, did unrar fail?")
+            self._log(_("File {directory} doesn't exist, did unrar fail?").format(directory=self.directory))
             return False
 
         for ignore_file in self.IGNORED_FILESTRINGS:
             if ignore_file in self.directory:
-                self._log(f"File {self.directory} is ignored type, skipping")
+                self._log(_("File {directory} is ignored type, skipping").format(directory=self.directory))
                 return False
 
         # reset per-file stuff
@@ -896,7 +956,8 @@ class PostProcessor(object):
         else:
             new_ep_quality = self._get_quality(ep_obj)
 
-        logger.debug(_(f"Quality of the episode we're processing: {common.Quality.qualityStrings[new_ep_quality]}"))
+        new_quality_string = common.Quality.qualityStrings[new_ep_quality]
+        logger.debug(_("Quality of the episode we're processing: {new_quality_string}").format(new_quality_string=new_quality_string))
 
         # see if this is a priority download (is it snatched, in history, PROPER, or BEST)
         priority_download = self._is_priority(ep_obj, new_ep_quality)
@@ -941,13 +1002,16 @@ class PostProcessor(object):
                     return False
 
                 # If the file season (ep_obj.season) is bigger than the indexer season (max_season[0][0]), skip the file
-                if int(ep_obj.season) > max_season[0][0]:
+                newest_season_num = max_season[0][0]
+                episode_season = ep_obj.season
+                if int(episode_season) > newest_season_num:
+
                     self._log(
                         _(
-                            f"File has season {ep_obj.season}, while the indexer is on season {max_season[0][0]}. "
+                            "File has season {episode_season}, while the indexer is on season {newest_season_num}. "
                             "Try forcing a full update on the show and process this file again. "
                             "The file may be incorrectly labeled or fake, aborting."
-                        )
+                        ).format(episode_season=episode_season, newest_season_num=newest_season_num)
                     )
                     return False
 
@@ -1037,7 +1101,7 @@ class PostProcessor(object):
         if releaseName:
             self.history.logSuccess(releaseName)
         else:
-            self._log(_("Couldn't find release in snatch history"), logger.WARNING)
+            self._log(_("Warning: Couldn't find release in snatch history"), logger.INFO)
 
         # find the destination folder
         try:
@@ -1058,7 +1122,7 @@ class PostProcessor(object):
             old_path = Path(self.filename)
             orig_extension = old_path.suffix
             new_base_name = os.path.basename(proper_path)
-            new_filename = f"{new_base_name}.{orig_extension}"
+            new_filename = f"{new_base_name}{orig_extension}"
         else:
             # if we're not renaming then there's no new base name, we'll just use the existing name
             new_base_name = None
@@ -1158,3 +1222,23 @@ class PostProcessor(object):
             logger.info(_("Some notifications could not be sent. Finishing postProcessing..."))
 
         return True
+
+
+def guessit_findit(name: str) -> Union["ParseResult", None]:
+    logger.debug(f"Trying a new way to verify if we can parse this file")
+    title = guessit(name, {"type": "episode"}).get("title")
+    if title:
+        show: "TVShow" = helpers.get_show(title, False)
+        if show:
+            try:
+                np = NameParser(showObj=show).parse(name, cache_result=False)
+                return np
+            except (InvalidNameException, InvalidShowException) as error:
+                logger.debug(f"Sorry, guessit failed to parse the file name for {show}: {name} (Error: {error} ... continuing with the old way")
+    try:
+        np = NameParser().parse(name, cache_result=False)
+        return np
+    except (InvalidNameException, InvalidShowException) as error:
+        logger.debug(f"Could not properly parse a show and episode from [{name}]: {error}")
+
+    return None
