@@ -4,6 +4,7 @@ import shutil
 import stat
 import traceback
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import validators
 from rarfile import BadRarFile, Error, NeedFirstVolume, PasswordRequired, RarCRCError, RarExecError, RarFile, RarOpenError, RarWrongPassword
@@ -15,6 +16,10 @@ from sickchill.helper.exceptions import EpisodePostProcessingFailedException, Fa
 from . import common, db, failedProcessor, helpers, postProcessor
 from .name_parser.parser import InvalidNameException, InvalidShowException, NameParser
 
+if TYPE_CHECKING:
+    from sickchill.oldbeard.name_parser.parser import ParseResult
+    from sickchill.tv import TVShow
+
 
 class ProcessResult(object):
     def __init__(self):
@@ -28,9 +33,9 @@ def delete_folder(folder, check_empty=True):
     """
     Removes a folder from the filesystem
 
-    :param folder: Path to folder to remove
-    :param check_empty: Boolean, check if the folder is empty before removing it, defaults to True
-    :return: True on success, False on failure
+    param folder: Path to folder to remove
+    param check_empty: Boolean, check if the folder is empty before removing it, defaults to True
+    return: True on success, False on failure
     """
 
     # check if it's a folder
@@ -41,7 +46,7 @@ def delete_folder(folder, check_empty=True):
     if settings.TV_DOWNLOAD_DIR and helpers.real_path(folder) == helpers.real_path(settings.TV_DOWNLOAD_DIR):
         return False
 
-    # check if it's empty folder when wanted checked
+    # check if it's empty folder when wanted to be checked
     if check_empty:
         check_files = os.listdir(folder)
         if check_files:
@@ -51,15 +56,15 @@ def delete_folder(folder, check_empty=True):
         try:
             logger.info(f"Deleting folder (if it's empty): {folder}")
             os.rmdir(folder)
-        except (OSError, IOError) as e:
-            logger.warning(f"Warning: unable to delete folder: {folder}: {str(e)}")
+        except (OSError, IOError) as error:
+            logger.warning(f"Warning: unable to delete folder: {folder}: {error}")
             return False
     else:
         try:
             logger.info("Deleting folder: " + folder)
             shutil.rmtree(folder)
-        except (OSError, IOError) as e:
-            logger.warning(f"Warning: unable to delete folder: {folder}: {str(e)}")
+        except (OSError, IOError) as error:
+            logger.warning(f"Warning: unable to delete folder: {folder}: {error}")
             return False
 
     return True
@@ -69,10 +74,10 @@ def delete_files(process_path, unwanted_files, result, force=False):
     """
     Remove files from filesystem
 
-    :param process_path: path to process
-    :param unwanted_files: files we do not want
-    :param result: Processor results
-    :param force: Boolean, force deletion, defaults to false
+    param process_path: path to process
+    param unwanted_files: files we do not want
+    param result: Processor results
+    param force: Boolean, force deletion, defaults to false
     """
     if not result.result and force:
         result.output += log_helper("Forcing deletion of files, even though last result was not success", logger.DEBUG)
@@ -94,12 +99,12 @@ def delete_files(process_path, unwanted_files, result, force=False):
             result.output += log_helper(f"Changing ReadOnly Flag for file: {cur_file}", logger.DEBUG)
             try:
                 os.chmod(cur_file_path, stat.S_IWRITE)
-            except OSError as e:
-                result.output += log_helper(f"Cannot change permissions of {cur_file_path}: {str(e)}", logger.DEBUG)
+            except OSError as error:
+                result.output += log_helper(f"Cannot change permissions of {cur_file_path}: {error}", logger.DEBUG)
         try:
             os.remove(cur_file_path)
-        except OSError as e:
-            result.output += log_helper(f"Unable to delete file {cur_file}: {e.strerror}", logger.DEBUG)
+        except OSError as error:
+            result.output += log_helper(f"Unable to delete file {cur_file}: {error}", logger.DEBUG)
 
 
 def log_helper(message, level=logging.INFO):
@@ -111,14 +116,14 @@ def process_dir(process_path, release_name=None, process_method=None, force=Fals
     """
     Scans through the files in process_path and processes whatever media files it finds
 
-    :param process_path: The folder name to look in
-    :param release_name: The NZB/Torrent name which resulted in this folder being downloaded
-    :param process_method: processing method, copy/move/symlink/link
-    :param force: True to process previously processed files
-    :param is_priority: whether to replace the file even if it exists at higher quality
-    :param delete_on: delete files and folders after they are processed (always happens with move and auto combination)
-    :param failed: Boolean for whether or not the download failed
-    :param mode: Type of postprocessing auto or manual
+    param process_path: The folder name to look in
+    param release_name: The NZB/Torrent name which resulted in this folder being downloaded
+    param process_method: processing method, copy/move/symlink/link
+    param force: True to process previously processed files
+    param is_priority: whether to replace the file even if it exists at higher quality
+    param delete_on: delete files and folders after they are processed (always happens with move and auto combination)
+    param failed: Boolean for whether the download failed
+    param mode: Type of postprocessing auto or manual
     """
     result = ProcessResult()
     try:
@@ -150,13 +155,13 @@ def process_dir(process_path, release_name=None, process_method=None, force=Fals
 
         # If we have a release name (probably from nzbToMedia), and it is a rar/video, only process that file
         if release_name and validators.url(release_name) == True:
-            result.output += log_helper(_(f"Processing {release_name}"), logger.INFO)
+            result.output += log_helper(_("Processing {release_name}").format(release_name=release_name))
             generator_to_use = [("", [], [release_name])]
         elif release_name and (is_media_file(release_name) or is_rar_file(release_name)):
-            result.output += log_helper(_(f"Processing {release_name}"), logger.INFO)
+            result.output += log_helper(_("Processing {release_name}").format(release_name=release_name))
             generator_to_use = [(process_path, [], [release_name])]
         else:
-            result.output += log_helper(_(f"Processing {process_path}"), logger.INFO)
+            result.output += log_helper(_("Processing {process_path}").format(process_path=process_path))
             generator_to_use = os.walk(process_path, followlinks=settings.PROCESSOR_FOLLOW_SYMLINKS)
 
         for current_directory, directory_names, filenames in generator_to_use:
@@ -171,7 +176,10 @@ def process_dir(process_path, release_name=None, process_method=None, force=Fals
                         for extracted_directory in extracted_directories:
                             if extracted_directory.split(current_directory)[-1] not in directory_names:
                                 result.output += log_helper(
-                                    _(f"Adding extracted directory to the list of directories to process: {extracted_directory}"), logger.DEBUG
+                                    _("Adding extracted directory to the list of directories to process: {extracted_directory}").format(
+                                        extracted_directory=extracted_directory
+                                    ),
+                                    logger.DEBUG,
                                 )
                                 directories_from_rars.add(extracted_directory)
 
@@ -191,12 +199,12 @@ def process_dir(process_path, release_name=None, process_method=None, force=Fals
             # noinspection PyTypeChecker
             unwanted_files = [x for x in filenames if x in video_files + rar_files]
             if unwanted_files:
-                result.output += log_helper(_(f"Found unwanted files: {unwanted_files}"), logger.DEBUG)
+                result.output += log_helper(_("Found unwanted files: {unwanted_files}").format(unwanted_files=unwanted_files), logger.DEBUG)
 
             delete_folder(os.path.join(current_directory, "@eaDir"), False)
             delete_files(current_directory, unwanted_files, result)
             if delete_folder(current_directory, check_empty=not delete_on):
-                result.output += log_helper(_(f"Deleted folder: {current_directory}"), logger.DEBUG)
+                result.output += log_helper(_("Deleted folder: {current_directory}").format(current_directory=current_directory), logger.DEBUG)
 
         # For processing extracted rars, only allow methods 'move' and 'copy'.
         # On different methods fall back to 'move'.
@@ -237,11 +245,11 @@ def validate_dir(process_path, release_name, failed, result):
     """
     Check if directory is valid for processing
 
-    :param process_path: Directory to check
-    :param release_name: Original NZB/Torrent name
-    :param failed: Previously failed objects
-    :param result: Previous results
-    :return: True if dir is valid for processing, False if not
+    param process_path: Directory to check
+    param release_name: Original NZB/Torrent name
+    param failed: Previously failed objects
+    param result: Previous results
+    returns True if dir is valid for processing, False if not
     """
 
     result.output += log_helper("Processing folder " + process_path, logger.DEBUG)
@@ -298,20 +306,12 @@ def validate_dir(process_path, release_name, failed, result):
         if settings.UNPACK == settings.UNPACK_PROCESS_CONTENTS:
             found_files += list(filter(is_rar_file, filenames))
 
-        # add directories if within main download location
-        if current_directory != settings.TV_DOWNLOAD_DIR and found_files:
-            found_files.append(os.path.basename(current_directory))
-
         for found_file in found_files:
             if current_directory != settings.TV_DOWNLOAD_DIR and found_files:
-                # add 'current directory + filename' as one string to list
-                found_files.append(f"{os.path.basename(current_directory)} {found_file}")
+                # pass 'current directory/filename' as one string to NameParser
+                found_file = f"{os.path.basename(current_directory)}/{found_file}"
 
-            try:
-                NameParser().parse(found_file, cache_result=False)
-            except (InvalidNameException, InvalidShowException) as error:
-                logger.debug(f"Could not properly parse a show and episode from [{found_file}]: {str(error)}")
-            else:
+            if postProcessor.guessit_findit(found_file):
                 return True
 
     result.output += log_helper(f"{process_path} : No processable items found in folder", logger.DEBUG)
@@ -322,11 +322,11 @@ def unrar(path, rar_files, force, result):
     """
     Extracts RAR files
 
-    :param path: Path to look for files in
-    :param rar_files: Names of RAR files
-    :param force: process currently processing items
-    :param result: Previous results
-    :return: List of unpacked file names
+    param path: Path to look for files in
+    param rar_files: Names of RAR files
+    param force: process currently processing items
+    param result: Previous results
+    returns List of unpacked file names
     """
 
     unpacked_dirs = []
@@ -362,7 +362,7 @@ def unrar(path, rar_files, force, result):
                 rar_release_name = Path(archive).stem
 
                 # Choose the directory we'll unpack to:
-                if settings.UNPACK_DIR and os.path.isdir(settings.UNPACK_DIR):  # verify the unpack dir exists
+                if settings.UNPACK_DIR and os.path.isdir(settings.UNPACK_DIR):  # verify that the unpacked dir exists
                     unpack_base_dir = settings.UNPACK_DIR
                 else:
                     unpack_base_dir = path
@@ -405,8 +405,8 @@ def unrar(path, rar_files, force, result):
                 failure = ("Invalid Rar Archive", "Unpacking Failed with an Invalid Rar Archive Error")
             except NeedFirstVolume:
                 continue
-            except (Exception, Error) as e:
-                failure = (str(e), "Unpacking failed")
+            except (Exception, Error) as error:
+                failure = (error, "Unpacking failed")
             finally:
                 if rar_handle:
                     del rar_handle
@@ -424,10 +424,10 @@ def already_processed(process_path, video_file, force, result):
     """
     Check if we already post processed a file
 
-    :param process_path: Directory a file resides in
-    :param video_file: File name
-    :param force: Force checking when already checking (currently unused)
-    :param result: True if file is already postprocessed, False if not
+    param process_path: Directory a file resides in
+    param video_file: File name
+    param force: Force checking when already checking (currently unused)
+    param result: True if file is already postprocessed, False if not
     :return:
     """
     if force:
@@ -442,21 +442,20 @@ def already_processed(process_path, video_file, force, result):
 
     # Needed if we have downloaded the same episode @ different quality
     # But we need to make sure we check the history of the episode we're going to PP, and not others
-    try:  # if it fails to find any info (because we're doing an unparsable folder (like the TV root dir) it will throw an exception, which we want to ignore
-        parse_result = NameParser(process_path, tryIndexers=True).parse(process_path)
-    except (
-        InvalidNameException,
-        InvalidShowException,
-    ):  # ignore the exception, because we kind of expected it, but create parse_result anyway so we can perform a check on it.
-        parse_result = False
+    # if it fails to find any info (because we're doing an unparsable folder (like the TV root dir) it will throw an exception, which we want to ignore
+    parse_result: "ParseResult" = postProcessor.guessit_findit(process_path)
 
     search_sql = "SELECT tv_episodes.indexerid, history.resource FROM tv_episodes INNER JOIN history ON history.showid=tv_episodes.showid"  # This part is always the same
     search_sql += " WHERE history.season=tv_episodes.season AND history.episode=tv_episodes.episode"
 
-    # If we find a showid, a season number, and one or more episode numbers then we need to use those in the query
-    if parse_result and parse_result.show.indexerid and parse_result.episode_numbers and parse_result.season_number:
-        search_sql += f" AND tv_episodes.showid={parse_result.show.indexerid} AND tv_episodes.season={parse_result.season_number}" \
-                      f" AND tv_episodes.episode={parse_result.episode_numbers[0]}"
+    # If we find a showid, a season number, and one or more episode numbers than we need to use those in the query
+    if parse_result:
+        if parse_result.show.indexerid:
+            search_sql += f" AND tv_episodes.showid={parse_result.show.indexerid}"
+        if parse_result.season_number is not None and parse_result.episode_numbers:
+            search_sql += f" AND tv_episodes.season={parse_result.season_number} AND tv_episodes.episode={parse_result.episode_numbers[0]}"
+        elif parse_result.ab_episode_numbers:
+            search_sql += f" AND tv_episodes.showid={parse_result.show.indexerid} AND tv_episodes.absolute_number={parse_result.ab_episode_numbers[0]}"
 
     search_sql += " AND tv_episodes.status IN (" + ",".join([str(x) for x in common.Quality.DOWNLOADED + common.Quality.ARCHIVED]) + ")"
     search_sql += " AND history.resource LIKE ? LIMIT 1"
@@ -472,13 +471,13 @@ def process_media(process_path, video_files, release_name, process_method, force
     """
     Postprocess mediafiles
 
-    :param process_path: Path to process in
-    :param video_files: Filenames to look for and postprocess
-    :param release_name: Name of NZB/Torrent file related
-    :param process_method: auto/manual
-    :param force: Postprocess currently postprocessing file
-    :param is_priority: Boolean, is this a priority download
-    :param result: Previous results
+    param process_path: Path to process in
+    param video_files: Filenames to look for and postprocess
+    param release_name: Name of NZB/Torrent file related
+    param process_method: auto/manual
+    param force: Postprocess currently postprocessing file
+    param is_priority: Boolean, is this a priority download
+    param result: Previous results
     """
 
     processor = None
@@ -493,9 +492,9 @@ def process_media(process_path, video_files, release_name, process_method, force
             processor = postProcessor.PostProcessor(cur_video_file_path, release_name, process_method, is_priority)
             result.result = processor.process()
             process_fail_message = ""
-        except EpisodePostProcessingFailedException as e:
+        except EpisodePostProcessingFailedException as error:
             result.result = False
-            process_fail_message = str(e)
+            process_fail_message = error
 
         if processor:
             result.output += processor.log
@@ -520,9 +519,9 @@ def process_failed(process_path, release_name, result):
         processor = failedProcessor.FailedProcessor(process_path, release_name)
         result.result = processor.process()
         process_fail_message = ""
-    except FailedPostProcessingFailedException as e:
+    except FailedPostProcessingFailedException as error:
         result.result = False
-        process_fail_message = str(e)
+        process_fail_message = error
 
     if processor:
         result.output += processor.log
@@ -534,28 +533,4 @@ def process_failed(process_path, release_name, result):
     if result.result:
         result.output += log_helper(f"Failed Download Processing succeeded: ({release_name}, {process_path})")
     else:
-        result.output += log_helper(
-            f"Failed Download Processing failed: ({release_name}, {process_path}): {process_fail_message}", logger.WARNING
-        )
-
-
-def subtitles_enabled(video):
-    """
-    Parse video filename to a show to check if it has subtitle enabled
-
-    :param video: video filename to be parsed
-    """
-
-    try:
-        parse_result = NameParser().parse(video, cache_result=True)
-    except (InvalidNameException, InvalidShowException):
-        logger.warning(f"Not enough information to parse filename into a valid show. Consider add scene exceptions or improve naming for: {video}")
-        return False
-
-    if parse_result.show.indexerid:
-        main_db_con = db.DBConnection()
-        sql_results = main_db_con.select("SELECT subtitles FROM tv_shows WHERE indexer_id = ? LIMIT 1", [parse_result.show.indexerid])
-        return bool(sql_results[0]["subtitles"]) if sql_results else False
-    else:
-        logger.warning(f"Empty indexer ID for: {video}")
-        return False
+        result.output += log_helper(f"Failed Download Processing failed: ({release_name}, {process_path}): {process_fail_message}", logger.WARNING)
