@@ -24,6 +24,8 @@ class Provider(TorrentProvider):
         self.minseed = 0
         self.minleech = 0
 
+        self.size_units = ["O", "Ko", "Mo", "Go", "To", "Po"]
+
         # URLs
         self.url = "https://abn.lol"
         self.urls = {
@@ -70,12 +72,9 @@ class Provider(TorrentProvider):
             "SortOn": "Created",
         }
 
-        # Units
-        units = ["O", "Ko", "Mo", "Go", "To", "Po"]
-
         for mode in search_strings:
             items = []
-            logger.debug(_("Search Mode: {mode}".format(mode=mode)))
+            logger.debug(_("Search Mode: {mode}").format(mode=mode))
 
             for search_string in {*search_strings[mode]}:
 
@@ -87,7 +86,7 @@ class Provider(TorrentProvider):
                 if not data:
                     continue
 
-                with BS4Parser(data, "html5lib") as html:
+                with BS4Parser(data) as html:
                     torrent_table = html.find(class_="table-rows")
                     torrent_rows = torrent_table("tr") if torrent_table else []
 
@@ -126,7 +125,7 @@ class Provider(TorrentProvider):
 
                             size_index = labels.index("Size") if "Size" in labels else labels.index("Taille")
                             torrent_size = cells[size_index].get_text()
-                            size = convert_size(torrent_size, units=units) or -1
+                            size = convert_size(torrent_size, units=self.size_units) or -1
 
                             item = {"title": title, "link": download_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": ""}
                             if mode != "RSS":
