@@ -31,10 +31,10 @@ class Provider(TorrentProvider):
 
         for mode in search_strings:
             items = []
-            logger.debug(_("Search Mode: {mode}".format(mode=mode)))
+            logger.debug(_("Search Mode: {mode}").format(mode=mode))
             for search_string in {*search_strings[mode]}:
                 if mode != "RSS":
-                    logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
+                    logger.debug(_("Search String: {search_string}").format(search_string=search_string))
                     search = slugify(search_string)
                     search_url = urljoin(self.url, "{}/{}/".format(search[0], search))
                 else:
@@ -51,7 +51,7 @@ class Provider(TorrentProvider):
                     logger.debug("URL did not return results/data, if the results are on the site maybe try a custom url, or a different one")
                     continue
 
-                with BS4Parser(data, "html5lib") as html:
+                with BS4Parser(data) as html:
                     torrent_table = html.find("table", class_="download")
                     torrent_body = torrent_table.find("tbody") if torrent_table else []
                     # noinspection PyCallingNonCallable
@@ -93,7 +93,8 @@ class Provider(TorrentProvider):
                                 logger.debug("Found result: {0} with {1} seeders and {2} leechers".format(title, seeders, leechers))
 
                             items.append(item)
-                        except Exception as e:
+                        except Exception as error:
+                            logger.debug(f"Failed parsing provider. Traceback: {error}")
                             continue
 
                 # For each search mode sort all the items by seeders if available
