@@ -61,14 +61,15 @@ class Provider(TorrentProvider):
 
             for search_string in {*search_strings[mode]}:
                 if mode != "RSS":
-                    logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
+                    logger.debug(_("Search String: {search_string}").format(search_string=search_string))
 
                 url = self.urls["search"] % search_string
                 data = self.get_url(url, returns="text")
 
                 try:
                     parsed_json = json.loads(data)
-                except ValueError as e:
+                except ValueError as error:
+                    logger.debug(f"Could not parse json from provider: {error}")
                     continue
 
                 if not isinstance(parsed_json, dict):
