@@ -1,12 +1,14 @@
+import traceback
+
 import validators
 
 from sickchill import logger
-from sickchill.helper.common import convert_size, try_int
 from sickchill.oldbeard import tvcache
+from sickchill.oldbeard.bs4_parser import BS4Parser
 from sickchill.providers.torrent.TorrentProvider import TorrentProvider
 
 
-class Provider(TorrentProvider):
+class Provider(TorrentProvider, tvcache.RSSTorrentMixin):
     def __init__(self):
 
         super().__init__("Nyaa")
@@ -22,6 +24,7 @@ class Provider(TorrentProvider):
         self.minleech = 0
         self.confirmed = False
 
+        self.size_units = ["BYTES", "KIB", "MIB", "GIB", "TIB", "PIB"]
         self.cache = tvcache.TVCache(self, min_time=20)  # only poll Nyaa every 20 minutes max
 
     def search(self, search_strings, age=0, ep_obj=None):
@@ -36,10 +39,10 @@ class Provider(TorrentProvider):
 
         for mode in search_strings:
             items = []
-            logger.debug(_(f"Search Mode: {mode}"))
+            logger.debug(_("Search Mode: {mode}").format(mode=mode))
             for search_string in {*search_strings[mode]}:
                 if mode != "RSS":
-                    logger.debug(_(f"Search String: {search_string}"))
+                    logger.debug(_("Search String: {search_string}").format(search_string=search_string))
 
                 search_params = {
                     "page": "rss",
@@ -52,37 +55,28 @@ class Provider(TorrentProvider):
                     search_params["q"] = search_string
 
                 results = []
-                data = self.cache.get_rss_feed(self.custom_url or self.url, params=search_params)["entries"]
+                data = self.get_url(self.custom_url or self.url, params=search_params)
                 if not data:
-                    logger.debug("Data returned from provider does not contain any torrents")
+                    logger.debug("No data was returned from the provider")
                     continue
 
-                for curItem in data:
-                    try:
-                        title = curItem["title"]
-                        download_url = curItem["link"]
-                        if not all([title, download_url]):
+                with BS4Parser(data, language="xml") as html:
+                    for item in html.find_all("item"):
+                        try:
+                            result = self.parse_feed_item(item, self.url, size_units=self.size_units)
+                            if result:
+                                if result["seeders"] < self.minseed or result["leechers"] < self.minleech:
+                                    if mode != "RSS":
+                                        logger.debug(
+                                            f"Discarding torrent because it doesn't meet the minimum seeders or leechers: {result['title']} (S:{result['seeders']} L:{result['leechers']})"
+                                        )
+                                    continue
+                                items.append(result)
+                        except Exception as error:
+                            logger.debug(f"Error parsing results: {error}")
+                            logger.debug(traceback.format_exc())
                             continue
 
-                        seeders = try_int(curItem["nyaa_seeders"])
-                        leechers = try_int(curItem["nyaa_leechers"])
-                        torrent_size = curItem["nyaa_size"]
-                        info_hash = curItem["nyaa_infohash"]
-
-                        if seeders < self.minseed or leechers < self.minleech:
-                            if mode != "RSS" or 1:
-                                logger.debug(f"Discarding torrent because it doesn't meet the minimum seeders or leechers: {title} (S:{seeders} L:{leechers})")
-                            continue
-
-                        size = convert_size(torrent_size, units=["BYTES", "KIB", "MIB", "GIB", "TIB", "PIB"]) or -1
-                        result = {"title": title, "link": download_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": info_hash}
-                        if mode != "RSS" or 1:
-                            logger.debug(_(f"Found result: {title} with {seeders} seeders and {leechers} leechers"))
-
-                        items.append(result)
-                    except Exception:
-                        continue
-
             # For each search mode sort all the items by seeders
             items.sort(key=lambda d: d.get("seeders", 0), reverse=True)
             results += items
