@@ -85,12 +85,12 @@ class ShowQueue(generic_queue.GenericQueue):
             raise CantUpdateShowException(f"{show.name} is still being added, wait until it is finished before you update.")
 
         if self.is_being_updated(show):
-            raise CantUpdateShowException(f"{show.name} is already being updated by Post-processor or manually started, "
-                                          f"can't update again until it's done.")
+            raise CantUpdateShowException(f"{show.name} is already being updated by Post-processor or manually started, can't update again until it's done.")
 
         if self.is_in_update_queue(show):
-            raise CantUpdateShowException(f"{show.name} is in process of being updated by Post-processor or manually "
-                                          f"started, can't update again until it's done.")
+            raise CantUpdateShowException(
+                f"{show.name} is in process of being updated by Post-processor or manually started, can't update again until it's done."
+            )
 
         queue_item_obj = QueueItemUpdate(show, force=force)
         self.add_item(queue_item_obj)
@@ -346,7 +346,9 @@ class QueueItemAdd(ShowQueueItem):
         try:
             s = sickchill.indexer.series_by_id(indexerid=self.indexer_id, indexer=self.indexer, language=self.lang)
             if not s:
-                error_string = _(f"Could not find show with id:{self.indexer_id} on {sickchill.indexer.name(self.indexer)}, skipping")
+                error_string = _("Could not find show with id:{indexer_id} on {indexer}, skipping").format(
+                    indexer_id=self.indexer_id, indexer=sickchill.indexer.name(self.indexer)
+                )
 
                 logger.info(error_string)
                 ui.notifications.error(_("Unable to add show"), error_string)
@@ -358,7 +360,7 @@ class QueueItemAdd(ShowQueueItem):
             # Indexers provided series name
             if self.root_dir and not self.showDir:
                 if not s.seriesName:
-                    logger.info(_(f"Unable to get a show {self.showDir}, can't add the show"))
+                    logger.info(_("Unable to get a show {showDir}, can't add the show").format(showDir=self.showDir))
                     self._finish_early()
                     return
 
@@ -369,16 +371,16 @@ class QueueItemAdd(ShowQueueItem):
                         if year not in show_dir:
                             show_dir = f"{s.seriesName} {year}"
                     except (TypeError, ValueError):
-                        logger.info(_(f"Could not append the show year folder for the show: {show_dir}"))
+                        logger.info(_("Could not append the show year folder for the show: {show_dir}").format(show_dir=show_dir))
 
                 self.showDir = os.path.join(self.root_dir, sanitize_filename(show_dir))
 
                 if settings.ADD_SHOWS_WO_DIR:
-                    logger.info(_(f"Skipping initial creation of {self.showDir} due to config.ini setting"))
+                    logger.info(_("Skipping initial creation of {showDir} due to config.ini setting").format(showDir=self.showDir))
                 else:
                     dir_exists = makeDir(self.showDir)
                     if not dir_exists:
-                        logger.info(_(f"Unable to create the folder {self.showDir}, can't add the show"))
+                        logger.info(_("Unable to create the folder {showDir}, can't add the show").format(showDir=self.showDir))
                         self._finish_early()
                         return
 
@@ -387,8 +389,10 @@ class QueueItemAdd(ShowQueueItem):
             # this usually only happens if they have an NFO in their show dir which gave us a Indexer ID that has no proper english version of the show
             if getattr(s, "seriesName", None) is None:
                 # noinspection PyPep8
-                error_string = _(f"Show in {self.showDir} has no name on {sickchill.indexer.name(self.indexer)}, probably "
-                                 f"searched with the wrong language. Delete .nfo and add manually in the correct language.")
+                error_string = _(
+                    "Show in {showDir} has no name on {indexer}, probably "
+                    "searched with the wrong language. Delete .nfo and add manually in the correct language."
+                ).format(showDir=self.showDir, indexer=sickchill.indexer.name(self.indexer))
 
                 logger.warning(error_string)
                 ui.notifications.error(_("Unable to add show"), error_string)
@@ -396,8 +400,10 @@ class QueueItemAdd(ShowQueueItem):
                 self._finish_early()
                 return
         except Exception as error:
-            error_string = f"Unable to look up the show in {self.showDir} on {sickchill.indexer.name(self.indexer)} " \
-                           f"using ID {self.indexer_id}, not using the NFO. Delete .nfo and try adding manually again."
+            error_string = (
+                f"Unable to look up the show in {self.showDir} on {sickchill.indexer.name(self.indexer)} "
+                f"using ID {self.indexer_id}, not using the NFO. Delete .nfo and try adding manually again."
+            )
 
             logger.exception(f"{error_string}: {error}")
             ui.notifications.error(_("Unable to add show"), error_string)
@@ -439,7 +445,7 @@ class QueueItemAdd(ShowQueueItem):
             self.show.paused = self.paused if self.paused is not None else False
 
             # set up default new/missing episode status
-            logger.info(_(f"Setting all episodes to the specified default status: {self.show.default_ep_status}"))
+            logger.info(_("Setting all episodes to the specified default status: {default_status}").format(default_status=self.default_status))
             self.show.default_ep_status = self.default_status
 
             if self.show.anime:
@@ -471,14 +477,14 @@ class QueueItemAdd(ShowQueueItem):
             return
 
         except MultipleShowObjectsException:
-            error_string = _(f"The show in {self.showDir} is already in your show list, skipping")
+            error_string = _("The show in {showDir} is already in your show list, skipping").format(showDir=self.showDir)
             logger.warning(error_string)
             ui.notifications.error(_("Show skipped"), error_string)
 
             self._finish_early()
             return
 
-        self.show.load_imdb_imfo()
+        self.show.load_imdb_info()
 
         try:
             self.show.saveToDB()
@@ -655,7 +661,7 @@ class QueueItemUpdate(ShowQueueItem):
             self.finish()
             return
 
-        self.show.load_imdb_imfo()
+        self.show.load_imdb_info()
 
         # have to save show before reading episodes from db
         try:
@@ -726,7 +732,7 @@ class QueueItemRemove(ShowQueueItem):
             try:
                 settings.traktCheckerScheduler.action.removeShowFromTraktLibrary(self.show)
             except Exception as error:
-                logger.warning(_(f"Unable to delete show from Trakt: {self.show.name}. Error: {error}"))
+                logger.warning(_("Unable to delete show from Trakt: {show_name}. Error: {error}").format(show_name=self.show.name, error=error))
 
         # If any notification fails, don't stop removal
         try:
