@@ -93,13 +93,12 @@ class ConfigGeneral(Config):
         https_key=None,
         handle_reverse_proxy=None,
         sort_article=None,
+        grammar_articles=None,
         auto_update=None,
         notify_on_update=None,
         proxy_setting=None,
         proxy_indexers=None,
         anon_redirect=None,
-        git_path=None,
-        git_remote=None,
         calendar_unprotected=None,
         calendar_icons=None,
         debug=None,
@@ -122,13 +121,13 @@ class ConfigGeneral(Config):
         sickchill_background_path=None,
         custom_css=None,
         custom_css_path=None,
-        git_reset=None,
         git_username=None,
         git_token=None,
         display_all_seasons=None,
         gui_language=None,
         ignore_broken_symlinks=None,
         ended_shows_update_interval=None,
+        log_dir=None,
     ):
 
         results = []
@@ -150,6 +149,8 @@ class ConfigGeneral(Config):
         settings.NOTIFY_ON_UPDATE = config.checkbox_to_value(notify_on_update)
         settings.LOG_NR = log_nr
         settings.LOG_SIZE = float(log_size)
+        if not config.change_log_dir(log_dir):
+            results += [_("Unable to create directory {log_dir} or it is not writable, log directory not changed.").format(log_dir=os.path.normpath(log_dir))]
         settings.WEB_LOG = config.checkbox_to_value(web_log)
 
         settings.TRASH_REMOVE_SHOW = config.checkbox_to_value(trash_remove_show)
@@ -158,6 +159,7 @@ class ConfigGeneral(Config):
         config.change_update_frequency(update_frequency)
         settings.LAUNCH_BROWSER = config.checkbox_to_value(launch_browser)
         settings.SORT_ARTICLE = config.checkbox_to_value(sort_article)
+        settings.GRAMMAR_ARTICLES = grammar_articles
         settings.CPU_PRESET = cpu_preset
         settings.ANON_REDIRECT = anon_redirect
         settings.PROXY_SETTING = proxy_setting
@@ -173,11 +175,6 @@ class ConfigGeneral(Config):
             settings.GIT_TOKEN = tmp_git_token
             setup_github()
 
-        # oldbeard.GIT_RESET = config.checkbox_to_value(git_reset)
-        # Force GIT_RESET
-        settings.GIT_RESET = 1
-        settings.GIT_PATH = git_path
-        settings.GIT_REMOTE = git_remote
         settings.CALENDAR_UNPROTECTED = config.checkbox_to_value(calendar_unprotected)
         settings.CALENDAR_ICONS = config.checkbox_to_value(calendar_icons)
         settings.NO_RESTART = config.checkbox_to_value(no_restart)
